@@ -6,6 +6,7 @@ perftools.middleware.slowreq
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
+import inspect
 import logging
 import thread
 import threading
@@ -24,6 +25,7 @@ except ImportError:
     # Wrapper to provide the same interface as the one from Python >= 2.5
     threadframe = lambda: _threadframe.dict()
 
+
 class SlowRequestLoggingMiddleware(Base):
     def __init__(self, application, threshold=1, stacks=True, logger=None, **kwargs):
         self.application = application
@@ -50,15 +52,7 @@ class SlowRequestLoggingMiddleware(Base):
         return threadframe()[parent_id]
 
     def get_frames(self, frame):
-        # TODO: look into using inspect.getouterframes()
-        frames = []
-        while frame:
-            frames.append(frame)
-            frame = frame.f_back
-
-        frames = frames[::-1]
-
-        return frames
+        return inspect.getouterframes(frame)
 
     def log_request(self, parent_id, request):
         try:
@@ -80,4 +74,4 @@ class SlowRequestLoggingMiddleware(Base):
             'data': {
                 'threshold': self.threshold,
             }
-        })
\ No newline at end of file
+        })
